(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[197],{9014:function(n,e,t){(window.__NEXT_P=window.__NEXT_P||[]).push(["/404",function(){return t(9622)}])},9622:function(n,e,t){"use strict";t.r(e);var u=t(5893),r=t(9008),i=t(2354);e.default=function(){return(0,u.jsxs)(u.Fragment,{children:[(0,u.jsx)(r.default,{children:(0,u.jsx)("title",{children:"Not Found"})}),(0,u.jsx)(i.D,{children:"Not Found"}),(0,u.jsx)("p",{children:"404: We couldn't find the page."})]})}}},function(n){n.O(0,[774,888,179],(function(){return e=9014,n(n.s=e);var e}));var e=n.O();_N_E=e}]);