self.__BUILD_MANIFEST=function(s,a){return{__rewrites:{beforeFiles:[],afterFiles:[{source:"/api/:path*"}],fallback:[]},"/":[s,a,"static/chunks/pages/index-ae432b41726f63f7.js"],"/404":["static/chunks/pages/404-5d906dae850e37e0.js"],"/_error":["static/chunks/pages/_error-2280fa386d040b66.js"],"/search":[s,a,"static/chunks/pages/search-63de02e831342d21.js"],sortedPages:["/","/404","/_app","/_error","/search"]}}("static/chunks/604-39b6c6beebc3af4a.js","static/chunks/343-2d311e2c5d4dca4e.js"),self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();